@@ -29,6 +29,7 @@ warnings.filterwarnings("ignore")
 16. 封装指数排行榜接口；
 17. 封装关键词落词列表接口；
 18. 获取免费、付费、畅销榜单产品列表；
+19. 获取产品预估下载量数据；
 
 '''
 
@@ -887,6 +888,26 @@ class Get_FreePaidGross_RankList(Qimai_Diy_Var):
                 break
         return self.app_grossRank_list
 
+# 获取预估下载量及预估收入接口；
+class Get_AppDownRevenue_Data(Qimai_Diy_Var):
+    def __init__(self, appid, start_date, end_date):
+        Qimai_Diy_Var.__init__(self)
+        self.appid = appid
+        self.start_date = start_date
+        self.end_date = end_date
+
+    def get_down_data(self):
+        url = 'https://api.qimai.cn/pred/download?appid=%s&country=%s&sdate=%s&edate=%s&platform=%s' %(self.appid, self.country, self.start_date, self.end_date, self.device)
+        res = session.get(url, headers=headers)
+        self.app_downNum_list = res.json()
+        return self.app_downNum_list
+
+    def get_revenue_data(self):
+        url = 'https://api.qimai.cn/pred/revenue?appid=%s&country=%s&sdate=%s&edate=%s&platform=%s' %(self.appid, self.country, self.start_date, self.end_date, self.device)
+        res = session.get(url, headers=headers)
+        self.app_revenueNum_list = res.json()
+        return self.app_revenueNum_list
+
 
 
 
